playwright: High-level API to automate web browsers
===================================================

Description
-----------

High-level API to automate web browsers

SageMath uses Playwright to take screenshots of 3D graphics in a headless browser.
Exporting Jupyter notebooks to PDF via nbconvert's WebPDF technology also uses Playwright.

License
-------

Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/playwright/

